Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(434)

Unified Diff: remoting/host/native_messaging/native_messaging_reader.cc

Issue 1547473005: Switch to standard integer types in remoting/host/. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 5 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: remoting/host/native_messaging/native_messaging_reader.cc
diff --git a/remoting/host/native_messaging/native_messaging_reader.cc b/remoting/host/native_messaging/native_messaging_reader.cc
index 2b768f3be8ded93a8b7c6448b6d625b8d5e4644b..f7df74d59dbbc9527c724d36b4969807f3507922 100644
--- a/remoting/host/native_messaging/native_messaging_reader.cc
+++ b/remoting/host/native_messaging/native_messaging_reader.cc
@@ -4,12 +4,15 @@
#include "remoting/host/native_messaging/native_messaging_reader.h"
+#include <stdint.h>
+
#include <string>
#include "base/bind.h"
#include "base/files/file.h"
#include "base/json/json_reader.h"
#include "base/location.h"
+#include "base/macros.h"
#include "base/sequenced_task_runner.h"
#include "base/single_thread_task_runner.h"
#include "base/stl_util.h"
@@ -19,8 +22,8 @@
namespace {
-// uint32 is specified in the protocol as the type for the message header.
-typedef uint32 MessageLengthType;
+// uint32_t is specified in the protocol as the type for the message header.
+typedef uint32_t MessageLengthType;
const int kMessageHeaderSize = sizeof(MessageLengthType);

Powered by Google App Engine
This is Rietveld 408576698